#[non_exhaustive]pub struct OrderWire {
pub asset: u32,
pub is_buy: bool,
pub limit_px: String,
pub sz: String,
pub reduce_only: bool,
pub order_type: OrderTypeWire,
pub cloid: Option<String>,
}Expand description
Wire format for an order sent to the Hyperliquid exchange.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset: u32Asset index (perp index or spot index with offset).
is_buy: boolWhether this is a buy order.
limit_px: StringLimit price as a decimal string.
sz: StringSize as a decimal string.
reduce_only: boolWhether the order is reduce-only.
order_type: OrderTypeWireOrder type wire format.
cloid: Option<String>Optional client order ID.
Implementations
Sourceimpl OrderWire
impl OrderWire
Sourcepub fn limit_buy(asset: u32, limit_px: Decimal, sz: Decimal) -> OrderWireBuilder
pub fn limit_buy(asset: u32, limit_px: Decimal, sz: Decimal) -> OrderWireBuilder
Start building a limit buy order.
Defaults to Tif::Gtc, reduce_only = false, no cloid.
Example
use hl_types::{OrderWire, Tif};
use rust_decimal::Decimal;
use std::str::FromStr;
let order = OrderWire::limit_buy(0, Decimal::from(90000), Decimal::from_str("0.001").unwrap())
.tif(Tif::Gtc)
.cloid("my-order-1")
.build()
.unwrap();
assert!(order.is_buy);
assert_eq!(order.limit_px, "90000");Sourcepub fn limit_sell(
asset: u32,
limit_px: Decimal,
sz: Decimal,
) -> OrderWireBuilder
pub fn limit_sell( asset: u32, limit_px: Decimal, sz: Decimal, ) -> OrderWireBuilder
Start building a limit sell order.
Defaults to Tif::Gtc, reduce_only = false, no cloid.
Sourcepub fn trigger_buy(
asset: u32,
trigger_px: Decimal,
sz: Decimal,
tpsl: Tpsl,
) -> OrderWireBuilder
pub fn trigger_buy( asset: u32, trigger_px: Decimal, sz: Decimal, tpsl: Tpsl, ) -> OrderWireBuilder
Start building a trigger buy order (e.g. stop-loss or take-profit).
Trigger orders fire as market orders when the trigger price is hit.
Defaults to reduce_only = true, no cloid.
Sourcepub fn trigger_sell(
asset: u32,
trigger_px: Decimal,
sz: Decimal,
tpsl: Tpsl,
) -> OrderWireBuilder
pub fn trigger_sell( asset: u32, trigger_px: Decimal, sz: Decimal, tpsl: Tpsl, ) -> OrderWireBuilder
Start building a trigger sell order (e.g. stop-loss or take-profit).
Trigger orders fire as market orders when the trigger price is hit.
Defaults to reduce_only = true, no cloid.